@@ -24,32 +24,57 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.ui" line="56"/>
+        <location filename="../configuredialog/configuredialog.ui" line="46"/>
+        <source>Show history first</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="53"/>
+        <source>Store/show history</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="60"/>
+        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="63"/>
+        <source>Show list with:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="70"/>
+        <source> item(s)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuredialog/configuredialog.ui" line="90"/>
         <source>Shortcut:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.cpp" line="60"/>
+        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
         <source>Top edge of the screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
+        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
         <source>Center of the screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
+        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
         <source>Focused screen</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
+        <location filename="../configuredialog/configuredialog.cpp" line="72"/>
         <source>Always on screen %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
+        <location filename="../configuredialog/configuredialog.cpp" line="81"/>
         <source>Reset</source>
         <translation type="unfinished"></translation>
     </message>
@@ -62,17 +87,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="92"/>
+        <location filename="../dialog.cpp" line="94"/>
         <source>Configure</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="96"/>
+        <location filename="../dialog.cpp" line="98"/>
         <source>Clear History</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="337"/>
+        <location filename="../dialog.cpp" line="351"/>
         <source>Show/hide runner dialog</source>
         <translation type="unfinished"></translation>
     </message>
@@ -80,19 +105,14 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../providers.cpp" line="388"/>
+        <location filename="../providers.cpp" line="445"/>
         <source>History</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="779"/>
+        <location filename="../providers.cpp" line="824"/>
         <source>Mathematics</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../providers.cpp" line="840"/>
-        <source>Power Management</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 </TS>
